@@ -2,7 +2,7 @@ import os
 import sys
 from ConfigParser import SafeConfigParser
 
-from .task import TaskCode
+from .task import Task
 
 class Config(object):
     def __init__(self, config_path=None, debug=False):
@@ -22,7 +22,7 @@ class Config(object):
     def load_task(self, name):
         task_path = self.config.get(name, 'task')
         module = import_task(task_path)
-        return TaskCode(name, module)
+        return Task(name, module)
 
     def tasks(self):
         return [x.strip() for x in self.config.sections()]
