@@ -1,5 +1,6 @@
 import logging
 import gevent
+import sys
 from collections import defaultdict
 from kafka import KafkaClient
 
@@ -83,7 +84,7 @@ class TaskContainer(object):
             server_offsets[topic][partition_id] = server_max
 
         for task in sorted(self.tasks, key=lambda x: x.name):
-            print task.name
+            print >>sys.stderr, task.name
 
             for topic in sorted(task.source_topics):
                 server_topic_offsets = server_offsets[topic]
@@ -94,4 +95,4 @@ class TaskContainer(object):
                         continue
                     task_offset = instance.offsets.get(topic)
                     lag = server_offset - task_offset
-                    print '\t{0}:{1} {2}/{3} ({4} lag)'.format(topic, partition_id, task_offset, server_offset, lag)
+                    print >>sys.stderr, '\t{0}:{1} {2}/{3} ({4} lag)'.format(topic, partition_id, task_offset, server_offset, lag)
